==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebRatingSymbolDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRatingSymbolDescription } from "./WebRatingSymbolDescription";
/**
 * @hidden
 */
export let WebRatingSymbolDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRatingSymbolDescriptionMetadata extends Base {
        static b(a) {
            if (WebRatingSymbolDescriptionMetadata.a == null) {
                WebRatingSymbolDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRatingSymbolDescriptionMetadata.c(WebRatingSymbolDescriptionMetadata.a);
            }
            if (a.j(WebRatingSymbolDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRatingSymbolDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RatingSymbol");
            a.item("__tagNameWC", "String:igc-rating-symbol");
        }
        static d(a) {
            WebRatingSymbolDescriptionMetadata.b(a);
            a.aa("WebRatingSymbol", () => new WebRatingSymbolDescription());
            a.z("WebRatingSymbol", WebRatingSymbolDescriptionMetadata.a);
        }
    }
    WebRatingSymbolDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRatingSymbolDescriptionMetadata, 'WebRatingSymbolDescriptionMetadata');
    WebRatingSymbolDescriptionMetadata.a = null;
    return WebRatingSymbolDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRatingSymbolDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRatingSymbolDescription } from "./WebRatingSymbolDescription";
/**
 * @hidden
 */
export let WebRatingSymbolDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRatingSymbolDescriptionMetadata extends Base {
        static b(a) {
            if (WebRatingSymbolDescriptionMetadata.a == null) {
                WebRatingSymbolDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRatingSymbolDescriptionMetadata.c(WebRatingSymbolDescriptionMetadata.a);
            }
            if (a.k(WebRatingSymbolDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRatingSymbolDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RatingSymbol");
            a.item("__tagNameWC", "String:igc-rating-symbol");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebRatingSymbolDescriptionMetadata.b(a);
            a.ac("WebRatingSymbol", () => new WebRatingSymbolDescription());
            a.ab("WebRatingSymbol", WebRatingSymbolDescriptionMetadata.a);
        }
    }
    WebRatingSymbolDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRatingSymbolDescriptionMetadata, 'WebRatingSymbolDescriptionMetadata');
    WebRatingSymbolDescriptionMetadata.a = null;
    return WebRatingSymbolDescriptionMetadata;
})();
